(on-complement-of matcher)Takes a matcher and returns a matcher that matches its complement.
Examples:
(on-complement-of (on-type :do-not-match)) will match all types that
are not :do-not-match(on-complement-of (on-types [:do-not-match-1 :do-not-match-2])) will
match all types that are not :do-not-match-1 or :do-not-match-2(on-complement-of (on :do-not-process)) will match all events that
have a falsy property :do-not-processTakes a matcher and returns a matcher that matches its complement.
Examples:
- `(on-complement-of (on-type :do-not-match))` will match all types that
are not `:do-not-match`
- `(on-complement-of (on-types [:do-not-match-1 :do-not-match-2]))` will
match all types that are not `:do-not-match-1` or `:do-not-match-2`
- `(on-complement-of (on :do-not-process))` will match all events that
have a falsy property `:do-not-process`cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |